// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
//	test the cal rawx2mm calls
//
#include <fstream>
#include <iostream>
#include "CalServer.h"
#include "Xmm.h"
#include "GeometryDataServer.h"
#include "common.h"

using namespace std;

int main()
{
	const XmmInstrument &ins = xmmPayLoad.rgs1;

	calServer.setInstrument(ins.id());
	calServer.state()->randomize()->set(false);
	calServer.state()->ccd()->set(9);
	calServer.state()->ocb()->set(1);

	unsigned nY = ins.maxY()-ins.minY()+1;
	CalInt16Vector rawXVec(0, nY),
				   rawYVec(0, nY);
	for (unsigned n=1; n<=nY; ++n) {
		rawXVec[n-1] = ins.minX();
		rawYVec[n-1] = n;
	}

	GeometryDataServer *cdf = 0; cdf = calServer.getAtom(cdf);
	XmmPixelList pl = cdf->chipCoordList(rawXVec, rawYVec);
	XmmCartesianPointList cpl =	pl.toCamCoord1().toCamCoord2().toSacCoord();
	XmmRowlandPointList rpl = cpl.toRowCoord();

	for (unsigned n=0; n<nY; ++n)
		cout<<setprecision(14)<<rpl.beta()[n]<<' '<<rpl.chi()[n]<<endl;

	return 0;
}
