// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	CalAtoms.cc --- implementation of atomic Cal functionality
//
//	DESCRIPTION:
//
//	CHANGE HISTORY:
//		UL, 1997-07-25: 1.0.0: - skeleton
//		UL, 1999-05-12: 1.1.0: - changed fatal -> error and changed all error
//								 tags
//
//	AUTHOR:
//		U. Lammers, Mon Oct  6 15:32:57 WET DST 1997
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al., 
//
//	$Header: /sasbuild/sas_git_repo/cvs_copy/sasdev/sas/packages/cal/src/CalAtomsBase.cc,v 1.14 2003/05/23 15:01:12 ulammers Exp $
//

#define CAL_ATOMS_C

#include "CalOalUtility.h"
#include "CalAtomsBase.h"
#include "Dal.h"
#include "errstr.h"
#include "stringutil.h"

using namespace std;

//
//	implemenatation part of CalAtom classes
//

bool CCDwindow::isPixelInside(const PixelLocation &pixel) const
{
	return  !(pixel.first < _xmin || pixel.first > _xmax ||
			 pixel.second < _ymin || pixel.second > _ymax);
} // CCDwindow::isPixelInside


unsigned CalAtomCollectionBase::index(unsigned modeNr) const
{
	if (modeNr > _nModes)
		errstr<<"mode number ("<<modeNr<<") out of bounds"
			  <<Sas::error("OutOfBounds");

	return modeNr;
} // CalAtomCollectionBase::index()


unsigned CalAtomCollectionBase::index(unsigned ccdNr, unsigned nodeNr)
const
{
	if (ccdNr <= 0 || ccdNr > _nCCDs || nodeNr >= _nNodes)
		errstr<<"CCD/node number ("<<ccdNr<<"/"<<nodeNr<<") out of bounds"
			  <<Sas::error("OutOfBounds");

	return _nNodes * (ccdNr-1) + // - 1 because first chip is #1
		   nodeNr;
} // CalAtomCollectionBase::index()


unsigned CalAtomCollectionBase::indexCcdMode(unsigned ccdNr, unsigned modeNr)
const
{
	if (ccdNr <= 0 || ccdNr > _nCCDs || modeNr >= _nModes)
		errstr<<"CCD/mode number ("<<ccdNr<<"/"<<modeNr<<") out of bounds"
			  <<Sas::error("OutOfBounds");

	return _nModes * (ccdNr-1) + // - 1 because first chip is #1
		   modeNr;
} // CalAtomCollectionBase::indexCcdMode()


unsigned CalAtomCollectionBase::index(
				unsigned ccdNr, unsigned nodeNr, unsigned modeNr) const
{
	if (ccdNr <= 0 || ccdNr > _nCCDs || nodeNr >= _nNodes || modeNr >= _nModes)
	  errstr<<"CCD/node/mode number ("<<ccdNr<<"/"<<nodeNr<<"/"<<modeNr
			<<") out of bounds"
			<<Sas::error("OutOfBounds");

	return _nNodes * _nModes * (ccdNr-1) +
		   _nModes * nodeNr +
		   modeNr;

} // CalAtomCollectionBase::index()
