// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	RmfEpochServer.h --- Cal atom to return RMF epochs
//
//	DESCRIPTION:
//
//	CHANGE HISTORY:
//		RDS, 2023-08-10: 1.0: - original
//
//	AUTHOR:
//		R. Saxton
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al., 
//
#ifndef RmfEpoch_H
#define RmfEpoch_H

#include "Ccf.h"
#include "CalAtomsBase.h"
#include "Image.h"

#include <vector>
#include <map>

//
//	---( mode parameters )------------------------------------------------
//
typedef std::pair<short, const string> Pair;

class RmfEpochServer : public CalAtom,
        public virtual CalChild<CalAtomCollection<RmfEpochServer> > { 
public:

	// Constructor
	RmfEpochServer(  std::vector<Pair> epochdate, 
                        CalAtomCollection<RmfEpochServer> *parent=0);

	static unsigned id() { return Ccf::RmfEpoch; };

        // Return requested map for an input date
        const short getRmfEpoch(const string &indate);

private:

        // A vector containing the epoch, start_date pairs
        std::vector<Pair> _epochdate;
};


#endif

